
# Slot: status

The status of the model in terms of its progression along the developmental lifecycle

URI: [gocam:model__status](https://w3id.org/gocam/model__status)


## Domain and Range

None &#8594;  <sub>0..1</sub> [ModelStateEnum](ModelStateEnum.md)

## Parents


## Children


## Used by

 * [Model](Model.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Aliases:** | | model state |
| **Mappings:** | | pav:status |
